@@ -143,7 +143,7 @@ saveout.net <- function(dat, s, out = NULL) {
       out$stats$nwstats <- list(dat$stats$nwstats)
     }
 
-    if (dat$control$tergmLite == FALSE) {
+    if (dat$control$save.transmat == TRUE) {
       if (!is.null(dat$stats$transmat)) {
         row.names(dat$stats$transmat) <- 1:nrow(dat$stats$transmat)
         out$stats$transmat <- list(dat$stats$transmat)
@@ -172,7 +172,7 @@ saveout.net <- function(dat, s, out = NULL) {
       out$stats$nwstats[[s]] <- dat$stats$nwstats
     }
 
-    if (dat$control$tergmLite == FALSE) {
+    if (dat$control$save.transmat == TRUE) {
       if (!is.null(dat$stats$transmat)) {
         row.names(dat$stats$transmat) <- 1:nrow(dat$stats$transmat)
         out$stats$transmat[[s]] <- dat$stats$transmat
@@ -203,7 +203,7 @@ saveout.net <- function(dat, s, out = NULL) {
       names(out$stats$nwstats) <- simnames
     }
 
-    if (dat$control$tergmLite == FALSE) {
+    if (dat$control$save.transmat == TRUE) {
       names(out$stats$transmat) <- simnames[1:length(out$stats$transmat)]
       names(out$network) <- simnames
     }
