@@ -43,7 +43,8 @@ test_that("get_network error flags", {
   expect_error(get_network(list(a = 1), 1), "must be of class netsim")
   expect_error(get_network(mod, 4), "Specify sim between 1 and 3")
   expect_error(get_network(mod, 1, collapse = TRUE), "Specify collapse time")
-  expect_error(get_network(mod, 1, collapse = TRUE, at = 200), "Specify collapse time")
+  expect_error(get_network(mod, 1, collapse = TRUE, at = 200),
+               "Specify collapse time")
   expect_error(get_network(mod, 1, 2), "Specify network")
 })
 
@@ -74,7 +75,8 @@ test_that("get_nwstats extracts data frame", {
 test_that("get_nwstats error flags", {
   expect_error(get_nwstats(list(a = 1)), "x must be of class netsim")
   expect_error(get_nwstats(mod, sim = 5))
-  expect_error(get_nwstats(mod, sim = 1, network = 2), "Specify network between 1")
+  expect_error(get_nwstats(mod, sim = 1, network = 2),
+               "Specify network between 1")
   mod$stats$nwstats <- NULL
   expect_error(get_nwstats(mod), "Network statistics not saved")
 })
@@ -95,5 +97,4 @@ test_that("get_sims extracts simulations", {
 test_that("get_sims error flags", {
   expect_error(get_sims(list(a = 1)), "x must be of class netsim")
   expect_error(get_sims(mod), "Specify sims as a vector")
-})
-
+})
\ No newline at end of file
