@@ -15,7 +15,8 @@ test_that("netest works for edges only model", {
 test_that("netest works for edges + nodematch model", {
   nw <- network_initialize(n = 50)
   nw <- set_vertex_attribute(nw, "race", rbinom(50, 1, 0.5))
-  est <- netest(nw, formation = ~edges + nodematch("race"), target.stats = c(25, 10),
+  est <- netest(nw, formation = ~edges + nodematch("race"),
+                target.stats = c(25, 10),
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                 verbose = FALSE)
   expect_is(est, "netest")
@@ -25,7 +26,8 @@ test_that("netest works for edges + nodematch model", {
 test_that("netest works with offset.coef terms", {
   nw <- network_initialize(n = 100)
   nw <- set_vertex_attribute(nw, "role", rep(c("I", "V", "R"), c(10, 80, 10)))
-  est <- netest(nw, formation = ~edges + offset(nodematch('role', diff = TRUE, keep = 1:2)),
+  est <- netest(nw, formation = ~edges + offset(nodematch("role", diff = TRUE,
+                                                          keep = 1:2)),
                 coef.form = c(-Inf, -Inf), target.stats = c(40),
                 coef.diss = dissolution_coefs(~offset(edges), 52 * 2, 0.0009),
                 verbose = FALSE)
@@ -39,9 +41,11 @@ test_that("netest works with offset.coef terms", {
 test_that("netest works for heterogeneous dissolutions", {
   nw <- network_initialize(n = 100)
   nw <- set_vertex_attribute(nw, "race", rbinom(50, 1, 0.5))
-  est <- netest(nw, formation = ~edges + nodematch("race"), target.stats = c(50, 20),
+  est <- netest(nw, formation = ~edges + nodematch("race"),
+                target.stats = c(50, 20),
                 coef.diss = dissolution_coefs(~offset(edges) +
-                                                offset(nodematch("race")), c(10, 20)),
+                                                offset(nodematch("race")),
+                                              c(10, 20)),
                 verbose = FALSE
   )
   expect_is(est, "netest")
@@ -61,17 +65,19 @@ test_that("netest diss_check flags bad models", {
   formation <- ~edges + nodematch("race", diff = TRUE)
   dissolution <- ~offset(edges) + offset(nodematch("race"))
   coef.diss <- dissolution_coefs(dissolution, c(10, 20))
-  expect_error(netest(nw, formation, target.stats = c(50, 20), coef.diss, verbose = FALSE),
+  expect_error(netest(nw, formation, target.stats = c(50, 20), coef.diss,
+                      verbose = FALSE),
                "Term options for one or more terms in dissolution model")
 })
 
 
-# Other tests -----------------------------------------------------------------------
+# Other tests ---------------------------------------------------------------
 
 test_that("Error if incorrect coef.diss parameter", {
   nw <- network_initialize(n = 50)
   coef.diss <- 1
-  expect_error(netest(nw, formation = ~edges, target.stats = 25, coef.diss = coef.diss,
+  expect_error(netest(nw, formation = ~edges, target.stats = 25,
+                      coef.diss = coef.diss,
                 verbose = FALSE))
 })
 
@@ -92,15 +98,19 @@ test_that("update_dissolution tests", {
                   coef.diss = diss.200)
 
   est200.compare <- update_dissolution(est300, diss.200)
-  expect_true(round(as.numeric(est200$coef.form, 3)) == round(as.numeric(est200.compare$coef.form, 3)))
+  expect_true(round(as.numeric(est200$coef.form, 3)) ==
+                round(as.numeric(est200.compare$coef.form, 3)))
 
-  expect_error(update_dissolution(1, diss.200), "old.netest must be an object of class netest")
-  expect_error(update_dissolution(est300, 1), "new.coef.diss must be an object of class disscoef")
+  expect_error(update_dissolution(1, diss.200),
+               "old.netest must be an object of class netest")
+  expect_error(update_dissolution(est300, 1),
+               "new.coef.diss must be an object of class disscoef")
   est300$edapprox <- FALSE
-  expect_error(update_dissolution(est300, diss.200), "Edges dissolution approximation must be used")
+  expect_error(update_dissolution(est300, diss.200),
+               "Edges dissolution approximation must be used")
 })
 
-# STERGM ----------------------------------------------------------------------------
+# STERGM --------------------------------------------------------------------
 
 test_that("Basic STERGM fit", {
   skip_on_cran()
