@@ -9,7 +9,8 @@ test_that("netsim par, 1 sim, 1 core", {
 
   param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsims = 1, nsteps = 5, ncores = 1, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 5, ncores = 1,
+                         verbose = FALSE)
   mod <- netsim(est, param, init, control)
   expect_is(mod, "netsim")
   expect_true(mod$control$nsims == 1)
@@ -27,7 +28,8 @@ test_that("netsim par, 2 sims, 2 cores", {
 
   param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsims = 2, nsteps = 5, ncores = 2, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 2, nsteps = 5, ncores = 2,
+                         verbose = FALSE)
   mod <- netsim(est, param, init, control)
   expect_is(mod, "netsim")
   expect_true(mod$control$nsims == 2)
@@ -44,7 +46,8 @@ test_that("netsim par, 1 sim, 2 cores", {
 
   param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsims = 1, nsteps = 5, ncores = 2, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 5, ncores = 2,
+                         verbose = FALSE)
   mod <- netsim(est, param, init, control)
   expect_is(mod, "netsim")
   expect_true(mod$control$nsims == 1)
@@ -61,7 +64,8 @@ test_that("netsim par, 2 sims, 1 cores", {
 
   param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsims = 2, nsteps = 5, ncores = 1, verbose = FALSE)
+  control <- control.net(type = "SI", nsims = 2, nsteps = 5, ncores = 1,
+                         verbose = FALSE)
   mod <- netsim(est, param, init, control)
   expect_is(mod, "netsim")
   expect_true(mod$control$nsims == 2)
